@@ -423,7 +423,7 @@ tooltip: true,
 
 								foreach ($this->monthly as $month => $data)
 								{
-									$xdata  .= '[' . $y . ', ' . $data['files']['total'] . ']';
+									$xdata  .= '[' . $y . ', ' . (isset($data['files']) ? $data['files']['total'] : 0) . ']';
 									$xdata  .= (($y + 1) == count($this->monthly)) ? '' : ',';
 									$xticks .= "[" . $y . ", '" . $month . "']";
 									$xticks .= (($y + 1) == count($this->monthly)) ? '' : ',';
@@ -461,8 +461,6 @@ tooltip: true,
 							<?php } ?>
 					<td class="stats-more">
 						<ul>
-							<li><span class="stats-num-small-unfloat"><?php echo $this->stats['files']['commits']; ?></span>
-							<?php echo Lang::txt('total Git commits'); ?></li>
 							<li><span class="stats-num-small-unfloat"><?php echo $this->stats['files']['diskspace']; ?></span>
 							<?php echo Lang::txt('total used disk space'); ?></li>
 						</ul>
