@@ -416,7 +416,7 @@ class plgMembersUsage extends \Hubzero\Plugin\Plugin
 	 *
 	 * @return  array
 	 */
-	public function getSerialResourceTypes()
+	public static function getSerialResourceTypes()
 	{
 		$database = App::get('db');
 
@@ -432,7 +432,7 @@ class plgMembersUsage extends \Hubzero\Plugin\Plugin
 	 * @param   integer  $parent_id
 	 * @return  array
 	 */
-	public function getSerialResourceChildren($parent_id)
+	public static function getSerialResourceChildren($parent_id)
 	{
 		$database = App::get('db');
 
